@@ -222,6 +222,9 @@ class TalosClientFactory:
         talosHttpClient.set_timeout(self._talosClientConfig.get_client_conn_timeout())
         return ConsumerClient(talosHttpClient)
 
+    def set_custom_headers(self, customHeaders=None):
+        self._customHeaders = customHeaders
+
     def new_message_client(self):
         headers = dict()
         headers[self._USER_AGENT_HEADER] = self.create_user_agent_header()
